toString method
Returns the cron expression as a string using CronExpressionOutputFormat.auto.
Implementation
@override
String toString() {
return toFormatString(CronExpressionOutputFormat.auto);
}
Returns the cron expression as a string using CronExpressionOutputFormat.auto.
@override
String toString() {
return toFormatString(CronExpressionOutputFormat.auto);
}