CronExpressionType enum

The type of cron expression format.

standard uses 5 parts: minute hour day month weekday. quartz uses 6-7 parts: second minute hour day month weekday year, and uses ? for "no specific value" in day/weekday fields.

Inheritance
Available extensions

Values

standard → const CronExpressionType
quartz → const CronExpressionType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CronExpressionType>
A constant List of the values in this enum, in order of their declaration.