CronExpressionOutputFormat enum

Controls how month and weekday values are formatted in output.

  • auto: preserves the original format (numeric or named).
  • allowedValues: always outputs numeric values (e.g., 1, 2).
  • alternativeValues: always outputs named values (e.g., JAN, MON).
Inheritance
Available extensions

Values

auto → const CronExpressionOutputFormat
allowedValues → const CronExpressionOutputFormat
alternativeValues → const CronExpressionOutputFormat

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isAlternative(bool isAlternative) bool

Available on CronExpressionOutputFormat, provided by the CronExpressionOutputFormatExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CronExpressionOutputFormat>
A constant List of the values in this enum, in order of their declaration.