CronPickerDialog class

A dialog for editing cron expressions with expandable panels.

Use CronPickerDialog.show as a convenient way to open the dialog:

final result = await CronPickerDialog.show(
  context: context,
  value: '0 0 */3 ? * *',
);
Inheritance

Constructors

CronPickerDialog({Key? key, required String value, String? title, @Deprecated('Use labels.done instead') String? btnDoneText, @Deprecated('Use labels.cancel instead') String? btnCancelText, CronExpressionOutputFormat outputFormat = CronExpressionOutputFormat.auto, CronPickerLabels labels = const CronPickerLabels()})
const

Properties

btnCancelText String?
final
btnDoneText String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labels CronPickerLabels
final
outputFormat CronExpressionOutputFormat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
value String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → CronPickerDialogState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required BuildContext context, required String value, String? title, String? btnDoneText, String? btnCancelText, CronExpressionOutputFormat outputFormat = CronExpressionOutputFormat.auto, CronPickerLabels labels = const CronPickerLabels()}) Future<String?>
Shows the cron picker dialog and returns the selected cron expression string, or null if cancelled.