CronPickerLabels class

Holds all user-facing strings used by CronPickerDialog.

Override individual labels to localize the picker:

CronPickerDialog(
  value: '* * * * *',
  labels: CronPickerLabels(
    seconds: 'Secondes',
    minutes: 'Minutes',
    done: 'Valider',
    cancel: 'Annuler',
  ),
)

Constructors

CronPickerLabels({String seconds = 'Seconds', String minutes = 'Minutes', String hourly = 'Hourly', String daily = 'Daily', String weekly = 'Weekly', String monthly = 'Monthly', String yearly = 'Yearly', String year = 'Year', String done = 'Done', String cancel = 'Cancel', String every = 'Every', String secondUnit = 'second(s)', String minuteUnit = 'minute(s)', String hoursOnMinute = 'hour(s) on minute', String daysAt = 'day(s) at', String startTime = 'Start time', String onThe = 'On the', String ofEvery = 'of every', String of = 'of', String at = 'at', String yearsStartingIn = 'year(s) starting in'})
const

Properties

at String
final
cancel String
final
daily String
final
daysAt String
final
done String
final
every String
final
hashCode int
The hash code for this object.
no setterinherited
hourly String
final
hoursOnMinute String
final
minutes String
final
minuteUnit String
final
monthly String
final
of String
final
ofEvery String
final
onThe String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seconds String
final
secondUnit String
final
startTime String
final
weekly String
final
year String
final
yearly String
final
yearsStartingIn String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited