CronFormField class
A form field for editing cron expressions via a picker dialog.
This widget wraps a read-only TextField that opens a CronPickerDialog when tapped. It supports both Standard and Quartz cron expression formats.
A Form ancestor is not required. The Form simply makes it easier to save, reset, or validate multiple fields at once. To use without a Form, pass a GlobalKey to the constructor and use GlobalKey.currentState to save or reset the form field.
When a controller is specified, its TextEditingController.text defines the initialValue. If this FormField is part of a scrolling container that lazily constructs its children, like a ListView or a CustomScrollView, then a controller should be specified.
If a controller is not specified, initialValue can be used to give the automatically generated controller an initial value.
CronFormField(
initialValue: '0 0 */3 ? * *',
labelText: 'Schedule',
onChanged: (val) => print(val),
onSaved: (val) => print(val),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FormField<
String> - CronFormField
Constructors
-
CronFormField({Key? key, TextEditingController? controller, InputDecoration? decoration, Widget? icon, String? labelText, String? hintText, String? dialogTitle, @Deprecated('Use labels.cancel instead') String? dialogCancelText, @Deprecated('Use labels.done instead') String? dialogDoneText, ValueChanged<
String> ? onChanged, ValueChanged<CronExpression> ? onCronExpressionChanged, CronExpressionOutputFormat outputFormat = CronExpressionOutputFormat.auto, CronPickerLabels labels = const CronPickerLabels(), String? initialValue, FocusNode? focusNode, TextStyle? style, TextAlign textAlign = TextAlign.start, TextAlignVertical? textAlignVertical, bool autofocus = false, bool readOnly = false, FormFieldSetter<String> ? onSaved, FormFieldValidator<String> ? validator, AutovalidateMode? autovalidateMode, bool enabled = true}) - Creates a CronFormField that contains a read-only TextField.
Properties
- autovalidateMode → AutovalidateMode
-
Used to enable/disable this form field auto validation and update its
error text.
finalinherited
-
builder
→ FormFieldBuilder<
String> -
Function that returns the widget representing this form field.
finalinherited
- controller → TextEditingController?
-
Controls the text being edited.
final
- decoration → InputDecoration?
-
The decoration to show around the text field.
final
- dialogCancelText → String?
-
The cancel button text on dialog.
final
- dialogDoneText → String?
-
The done button text on dialog.
final
- dialogTitle → String?
-
The title of the dialog window. Falls back to labelText if null.
final
- enabled → bool
-
Whether the form is able to receive user input.
finalinherited
- errorBuilder → FormFieldErrorBuilder?
-
Function that returns the widget representing the error to display.
finalinherited
- forceErrorText → String?
-
An optional property that forces the FormFieldState into an error state
by directly setting the FormFieldState.errorText property without
running the validator function.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
Text that suggests what sort of input the field accepts. Used in the
default decoration when decoration is null.
final
- icon → Widget?
-
An icon to show before the input field. Used in the default decoration
when decoration is null.
final
- initialValue → String?
-
An optional value to initialize the form field to, or null otherwise.
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labels → CronPickerLabels
-
Labels for the picker dialog. Override to localize.
final
- labelText → String?
-
Text that describes the input field. Used in the default decoration
when decoration is null, and as the dialog title fallback.
final
-
onChanged
→ ValueChanged<
String> ? -
Called when the string value changes.
final
-
onCronExpressionChanged
→ ValueChanged<
CronExpression> ? -
Called when the cron expression changes, providing the parsed
CronExpression object for direct access to individual parts.
final
- onReset → VoidCallback?
-
An optional method to call when the form field is reset via
FormFieldState.reset.
finalinherited
-
onSaved
→ FormFieldSetter<
String> ? -
An optional method to call with the final value when the form is saved via
FormState.save.
finalinherited
- outputFormat → CronExpressionOutputFormat
-
The output format for the cron expression.
final
- restorationId → String?
-
Restoration ID to save and restore the state of the form field.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validator
→ FormFieldValidator<
String> ? -
An optional method that validates an input. Returns an error string to
display if the input is invalid, or null otherwise.
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → CronFormFieldState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited